netapp_ontap.models.cluster_space_block_storage API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.cluster_space_block_storage`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ClusterSpaceBlockStorageSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ClusterSpaceBlockStorage object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `available: Size GET`

    Available space across the cluster.

  `delayed_frees: Size GET`

    Total delayed free space across the cluster.

  `full_threshold_percent: Size GET POST PATCH`

    The cluster space full threshold percentage that triggers an EMS error.

  `inactive_data: Size GET`

    Inactive data across the cluster.

  `log_and_recovery_metadata: Size GET`

    The total space consumed by system logs and cores in the cluster.

  `medias: List[ClusterSpaceBlockStorageMedias] GET`

    Configuration information based on type of media. For example, SSD media type information includes the sum of all the SSD storage across the cluster.

  `nearly_full_threshold_percent: Size GET POST PATCH`

    The cluster space nearly full threshold percentage that triggers an EMS warning.

  `physical_used: Size GET`

    Total physical used space across the cluster.

  `physical_used_percent: Size GET`

    The Physical space used percentage across the cluster.

  `size: Size GET`

    Total space across the cluster.

  `total_metadata_used: Size GET`

    The total space consumed by metadata in the cluster, which includes log and recovery metadata, delayed frees along with filesystem metadata and performance metadata.

  `unusable_space: Size GET`

    Total unusable space across the cluster due to some aggregate being unavailable.

  `used: Size GET`

    Used space (includes volume reserves) across the cluster.